Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Manual ¶ added in v1.3.0
func Manual()
Manual trigger for action execution.
Note that this will have no effect in case a signal has already been detected.
Types ¶
type Listener ¶
type Listener struct {
// contains filtered or unexported fields
}
Listener listens to signals and allows actions to be called whenever a signal is received.
func NewListener ¶
NewListener creates a new Listener instance with the given signals.
func (*Listener) Manual ¶ added in v1.3.0
func (l *Listener) Manual()
Manual trigger for action execution. This can be deferred in the main function to run cleanup actions even if no interruptions are detected.
Note that this will have no effect in case a signal has already been detected.
Click to show internal directories.
Click to hide internal directories.